# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# We need to patch the module if we have an old version of List::Util
%global old_list_util %(perl -MList::Util -e 'print (($List::Util::VERSION < 1.33) ? 1 : 0);' 2>/dev/null || echo 0)

Name:		perl-PPI
Version:	1.279
Release:	1.%{__distinit}%{__distvers}
Summary:	Parse, Analyze and Manipulate Perl
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/PPI
Source0:	https://cpan.metacpan.org/modules/by-module/PPI/PPI-%{version}.tar.gz
Patch0:		PPI-1.274-old-List::Util.patch
BuildArch:	noarch
# =============== Module Build ======================
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
BuildRequires:	perl(Task::Weaken)
BuildRequires:	perl(warnings)
# =============== Module Runtime ====================
BuildRequires:	perl(Carp)
BuildRequires:	perl(Clone) >= 0.30
BuildRequires:	perl(constant)
BuildRequires:	perl(Digest::MD5) >= 2.35
BuildRequires:	perl(Exporter)
BuildRequires:	perl(File::Path)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(if)
BuildRequires:	perl(List::MoreUtils)
BuildRequires:	perl(List::Util) >= 1.20
BuildRequires:	perl(overload)
BuildRequires:	perl(Params::Util) >= 1.00
BuildRequires:	perl(Scalar::Util)
BuildRequires:	perl(Storable) >= 2.17
BuildRequires:	perl(strict)
# =============== Optional Functionality ============
BuildRequires:	perl(Class::XSAccessor)
# =============== Test Suite ========================
BuildRequires:	perl(B)
BuildRequires:	perl(Class::Inspector) >= 1.22
BuildRequires:	perl(CPAN::Meta) >= 2.120900
BuildRequires:	perl(Encode)
BuildRequires:	perl(File::Copy)
BuildRequires:	perl(File::Spec::Functions)
BuildRequires:	perl(File::Temp)
BuildRequires:	perl(lib)
BuildRequires:	perl(parent)
BuildRequires:	perl(Test::More) >= 0.96
BuildRequires:	perl(Test::NoWarnings)
BuildRequires:	perl(Test::Object) >= 0.07
BuildRequires:	perl(Test::SubCalls) >= 1.07
BuildRequires:	perl(Test::Warnings)
BuildRequires:	perl(Time::HiRes)
BuildRequires:	perl(utf8)
# =============== Dependencies ======================
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
# For experimental PPI::XSAccessor (found automatically with rpm ≥ 4.12 [F-21 onwards])
Requires:	perl(Class::XSAccessor)
# Run-require Task::Weaken, see Changes for more details.
Requires:	perl(Task::Weaken)

# Filter out redundant unversioned provides
%global __provides_exclude ^perl\\(PPI::.+\\)$

%description
Parse, analyze and manipulate Perl (without perl).

%prep
%setup -q -n PPI-%{version}

# Fix bogus exec permissions
chmod -c -x Changes LICENSE README

# We need to patch the module if we have an old version of List::Util
%if %{old_list_util}
%patch -P 0
%endif

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%license LICENSE
%doc Changes README
%{perl_vendorlib}/PPI/
%{perl_vendorlib}/PPI.pm
%{_mandir}/man3/PPI*.3*

%changelog
* Fri Aug 23 2024 Paul Howarth <paul@city-fan.org> - 1.279-1
- Update to 1.279
  - Implemented a cache to speed up sibling iteration (GH#287)

* Mon Mar 11 2024 Paul Howarth <paul@city-fan.org> - 1.278-1
- Update to 1.278
  - Add support for new octal number syntax (GH#295)

* Fri Sep 22 2023 Paul Howarth <paul@city-fan.org> - 1.277-1
- Update to 1.277
  - Parse prototypes as literal quotes: enables parens and newlines in protos
  - Fix false positive detection of labels (GH#289)

* Mon May  8 2023 Paul Howarth <paul@city-fan.org> - 1.276-3
- Use SPDX-format license tag
- Avoid use of deprecated patch syntax

* Wed Jul 20 2022 Paul Howarth <paul@city-fan.org> - 1.276-1
- Update to 1.276
  - Implement replace method (GH#274)

* Tue Jul 19 2022 Paul Howarth <paul@city-fan.org> - 1.275-1
- Update to 1.275
  - CHECK bareword handle was parsed as scheduled block (GH#247)

* Tue May  3 2022 Paul Howarth <paul@city-fan.org> - 1.274-1
- Update to 1.274
  - Indentation in here-docs is now preserved (GH#252)

* Mon Apr 25 2022 Paul Howarth <paul@city-fan.org> - 1.273-1
- Update to 1.273
  - Whitespace in signatures is now preserved (GH#257)

* Wed Feb  2 2022 Paul Howarth <paul@city-fan.org> - 1.272-1
- Update to 1.272
  - Drop prerequisite for IO::String on perl 5.8+

* Wed Jan 26 2022 Paul Howarth <paul@city-fan.org> - 1.271-1
- Update to 1.271
  - Return correct name for lexical subroutines
  - Silence uninitialized warning in t/07_token.t
  - Bump minimum Test::More version to 0.96
  - Fix some typos in Pod
  - Moved repository to Perl-Critic GitHub org:
    https://github.com/Perl-Critic/PPI
- Assume we have rpm ≥ 4.9
- Use %%license unconditionally

* Wed Jul 10 2019 Paul Howarth <paul@city-fan.org> - 1.270-1
- Update to 1.270
  - Attempt to handle new blead binary/hexadecimal parsing behaviour in tests

* Wed Jun  5 2019 Paul Howarth <paul@city-fan.org> - 1.269-2
- Perl 5.30 rebuild

* Sun May 19 2019 Paul Howarth <paul@city-fan.org> - 1.269-1
- Update to 1.269
  - Many small documentation improvements

* Thu May 16 2019 Paul Howarth <paul@city-fan.org> - 1.268-1
- Update to 1.268
  - Make PPI::Test::Run more OS-agnostic
  - Fix a broken link in the pod

* Thu May 16 2019 Paul Howarth <paul@city-fan.org> - 1.266-1
- Update to 1.266
  - Prevent heredoc terminator detection triggering regex errors
  - Small clean-ups
- Work around test failures caused by DOS line endings in test data files
  (https://github.com/adamkennedy/PPI/issues/243)

* Wed May 15 2019 Paul Howarth <paul@city-fan.org> - 1.265-1
- Update to 1.265
  - Simplified a code construct

* Mon Apr 29 2019 Paul Howarth <paul@city-fan.org> - 1.264-1
- Update to 1.264
  - Keep vstring processing from swallowing underscores

* Sun Apr 28 2019 Paul Howarth <paul@city-fan.org> - 1.262-1
- Update to 1.262
  - Add support for the double diamond (<<>>) input operator
  - Adjust position of a todo marker to not catch a passing test
  - Recognize `for (;<$foo>;) {}` as containing a readline operator
  - Remove accidentally included use of Test::InDistDir
  - Allow all PPI::Document instances to have a filename attribute
  - Allow underscores in vstrings
  - Convert newlines in some raw test files from win32 to unix

* Fri Apr 26 2019 Paul Howarth <paul@city-fan.org> - 1.250-1
- Update to 1.250
  - Support postfix dereference
  - Add support for lexical subroutines from perl-5.26
  - Support key-value and index-value slices in PPI::Token::Symbol symbol
    method
  - Support indented here-docs
  - Parse list-embedded curlies as hash constructors
  - Keep exponents of 2 or more zeroes from trapping PPI in an endless loop
  - Remove dependencies on vars, base and List::MoreUtils
  - Remove dependency on File::Remove
  - Reduce globals and cross-package variables
  - Move to Dist::Zilla
  - Add some tests including a TODO test for misparse bug on '(1)-1'
  - Allow tests to run without pre-determined module versions
  - Make xt/api.t skip/run properly
  - Fix some typos and formatting in Changes
  - Add travis-perl helper to be run before install
  - Update versions of Perl Travis tests on
- Switch upstream from search.cpan.org to metacpan.org
- Don't try to run the release tests in the package build

* Mon Apr 16 2018 Paul Howarth <paul@city-fan.org> - 1.236-3
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop workaround for building with Perl::MinimumVersion < 1.25

* Thu Jun 22 2017 Paul Howarth <paul@city-fan.org> - 1.236-1
- Update to 1.236
  - Prevent Node->child from proceeding without a valid argument
  - Make test pragma warning code enable -w to match warnings policy

* Wed Jun 21 2017 Paul Howarth <paul@city-fan.org> - 1.234-1
- Update to 1.234
  - Prevent sub names like v10 from being version strings (GH#65)
  - Add Changes entries forgotten in 1.230
  - Remove temporary fix introduced in 1.226
  - Prevent possible regex on undefined scalar in
    __current_token_is_forced_word

* Wed Jun 21 2017 Paul Howarth <paul@city-fan.org> - 1.228-1
- Update to 1.228
  - Fix test reliance on '.' in @INC
  - Temporary fix to keep an untested combination from blocking Perl::Critic
  - Keep PPI::Dumper from breaking Perl::Critic under cperl 5.27

* Tue May 16 2017 Paul Howarth <paul@city-fan.org> - 1.224-1
- Update to 1.224
  - Unit tests for many parts, both passing and TODO
  - Many documentation fixes
  - Add ->version method to PPI::Statement::Package
  - Remove unused PPI::Document->new timeout feature
  - Do not expect '.' in @INC
  - Many parsing fixes
  - Various fixes to the behaviors of methods
  - Removal of problematic dependencies
- Add patch to switch back to List::MoreUtils if we don't have a new enough
  version of List::Util
- Add patch to fix warnings on older Perls prior to Fedora 19
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - Drop workaround for building with Test::More < 0.86

* Tue Jul 26 2016 Paul Howarth <paul@city-fan.org> - 1.220-7
- Fix FTBFS when perl is not in the minimal buildroot
- BR: perl-generators where available
- Simplify find command using -delete
- Prefer %%global over %%define

* Wed Nov 12 2014 Paul Howarth <paul@city-fan.org> - 1.220-1
- Update to 1.220
  - Incompatible behavior fixes on PPI::Statement::Sub->prototype
  - Improved parsing of various syntax elements
  - Code quality improvements
  - Various small documentation fixes
- BR:/R: perl(Class::XSAccessor) for experimental PPI::XSAccessor
- BR: perl(IO::All) and perl(Capture::Tiny) to quieten warnings for author
  code during module build
- Fix line endings of new README.md file

* Tue Sep  2 2014 Paul Howarth <paul@city-fan.org> - 1.218-2
- Perl 5.20 rebuild

* Mon Aug 25 2014 Paul Howarth <paul@city-fan.org> - 1.218-1
- Update to 1.218
  - Fixes for various parsing and documentation bugs
  - 1MB limit on input document size removed
  - Moved repository to GitHub: https://github.com/adamkennedy/PPI
- This release by MITHALDU → update source URL
- Use %%license where possible
- Drop %%defattr, redundant since rpm 4.4
- Update patches as needed

* Sat Aug 25 2012 Paul Howarth <paul@city-fan.org> - 1.215-9
- Bump perl(Clone) version requirement to 0.30
- Bump perl(File::Spec) version requirement to 0.84
- Bump perl(Test::NoWarnings) version requirement to 0.084
- Renumber patches to sync with Fedora package
- Run-require Task::Weaken; see Changes for more details

* Mon Jul 16 2012 Paul Howarth <paul@city-fan.org> - 1.215-6
- Perl 5.16 post-bootstrap rebuild

* Tue Jul 10 2012 Paul Howarth <paul@city-fan.org> - 1.215-5
- Classify buildreqs by usage
- BR: perl(Carp), perl(constant), perl(Cwd), perl(Digest::MD5), perl(Exporter),
  perl(ExtUtils::MakeMaker), perl(File::Path), perl(File::Spec),
  perl(File::Spec::Functions), perl(File::Spec::Unix), perl(Pod::Simple),
  perl(Scalar::Util) and perl(Time::HiRes)
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Fri Mar  2 2012 Paul Howarth <paul@city-fan.org> - 1.215-3
- Bump Params::Util version requirement to 1.00 as per upstream
- Don't need to remove empty directories from buildroot
- Don't need to fix permissions of files from tarball
- Use a patch rather than scripted iconv to fix character encoding

* Wed Jun 29 2011 Paul Howarth <paul@city-fan.org> - 1.215-2
- Rebuild for perl 5.14.1 in Rawhide
- Add support for perl_bootstrap macro
- Explicitly BR: Class::Inspector and Test::More
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Sat Feb 26 2011 Paul Howarth <paul@city-fan.org> - 1.215-1
- Updated to 1.215:
  - index_locations on an empty document no longer warns
  - Corrected a bug in line-spanning attribute support
  - Regression test for line-spanning attribute support
  - return { foo => 1 } should parse curlys as hash constructor, not block
    (CPAN RT#61305)
  - Fixed bug with map and regexp confusing PPI (CPAN RT#63943)
  - Updated copyright year to 2011 (ADAMK)
  - Fix bless {} probably contains a hash constructor (CPAN RT#64247)
  - Backed out glob fix
  - Fix cast can trump braces in PPI::Token::Symbol->symbol (CPAN RT#65199)

* Wed Jul  7 2010 Paul Howarth <paul@city-fan.org> - 1.213-1
- Updated to 1.213:
  - Updated to Module::Install 1.00
  - Updated module dependencies in xt author tests
  - Fixed extremely broken PPI::Token::Pod::merge and added test case
- Update Test::More downgrade patch
- Release tests moved to xt/
- BR: perl(File::Find::Rule) >= 0.32, perl(File::Find::Rule::Perl) >= 1.09,
  perl(Perl::MinimumVersion) >= 1.20 and perl(Test::MinimumVersion) >= 0.101080
  for release tests
- Downgrade Perl::MinimumVersion requirement to 1.20 if we don't have 1.25 or
  later, to support builds on older releases

* Wed Jun 23 2010 Paul Howarth <paul@city-fan.org> - 1.212-2
- Rebuild for perl 5.12.1 in Rawhide

* Sat May  8 2010 Paul Howarth <paul@city-fan.org> - 1.212-1
- Updated to 1.212:
  - Fixed bug in ForLoop back-compatibility warning (CPAN RT#48819)
  - Added support for $ENV{X_TOKENIZER} --> $PPI::Lexer::X_TOKENIZER
  - Upgraded to Module::Install 0.93
  - Added support for $PPI::Lexer::X_TOKENIZER, for alternate tokenizers
  - Added an extra test case to validate we handle byte order marks properly
  - Moved author tests from t to xt
  - Fixed CPAN RT#26082: scalar { %%x } is misparsed
  - Fixed CPAN RT#26591: VMS patch for PPI 1.118
  - Fixed CPAN RT#44862: PPI cannot parse "package Foo::100;" correctly
  - Fixed CPAN RT#54208: PPI::Token::Quote::Literal::literal missing
- Fix dist tag to work with RHEL6 Beta

* Tue Feb 16 2010 Paul Howarth <paul@city-fan.org> - 1.210-1
- Update to 1.210 (packaging fixes)
- Use RELEASE_TESTING rather than AUTOMATED_TESTING for better test coverage

* Sun Feb  7 2010 Paul Howarth <paul@city-fan.org> - 1.209-1
- Update to 1.209 (small optimization release)

* Wed Feb  3 2010 Paul Howarth <paul@city-fan.org> - 1.208-2
- Use %%{_fixperms} macro instead of our own %%{__chmod} incantation

* Fri Jan 15 2010 Paul Howarth <paul@city-fan.org> - 1.208-1
- Update to 1.208
  - Don't assign '' to $^W, it generates a warning on Gentoo
  - Added missing PPI::Token::Regexp fix to Changes file
  - Updating Copyright to the new year
  - Fixed #50309: literal() wrong result on "qw (a b c)"
  - PPI::Dumper no longer causes Elements to flush location data
  - PPI::Dumperno longer disables location information for non-Documents
  - +{ package => 1 } doesn't create a PPI::Statement::Package
  - Extra methods in PPI::Token::Regexp and PPI::Token::QuoteLike::Regexp
- Dist tag for Rawhide no longer needs special-casing

* Mon Aug 10 2009 Paul Howarth <paul@city-fan.org> - 1.206-1
- Update to 1.206 (optimisation release - 1-2% speed up)
- Add buildreq perl(Task::Weaken) for improved test coverage

* Mon Aug  3 2009 Paul Howarth <paul@city-fan.org> - 1.205-1
- Update to 1.205 (many updates - see Changes for details)
- Drop charsets.t patch, now upstream
- Drop Lexer patch for perl 5.8.0, problem fixed upstream
- Add provides filter to remove redundant unversioned provides
- Apply patch to downgrade Test::More requirement if we can't satisfy it

* Fri Jun  5 2009 Paul Howarth <paul@city-fan.org> - 1.203-1
- Update to 1.203
- Add workaround for "Can't use an undefined value as an ARRAY reference"
  error in Lexer.pm on RHL9, RHEL3
- Fix charsets.t to not gobble all available memory on FC4, FC4, RHEL4
  (RT#35917), and add associated buildreq perl(Test::NoWarnings)
- Re-add perl(Test::ClassAPI) buildreq
- Enable AUTOMATED_TESTING and add associated buildreq perl(Test::CPAN::Meta)
- Bump version requirements:
  perl(Clone) >= 0.25
  perl(File::Remove) >= 0.39
  perl(List::MoreUtils) >= 0.16
  perl(Params::Util) >= 0.17 (latest version possible on RHEL3)
  perl(Test::ClassAPI) >= 1.03
  perl(Test::Object) >= 0.07
  perl(Test::SubCalls) >= 1.07
- Update to SLES-compatible dist tag macros

* Mon Sep  1 2008 Paul Howarth <paul@city-fan.org> - 1.201-4
- Import from Fedora
- Fix character encoding of Changes file
- Drop version requirement of perl(List::Util) and perl(Storable) for builds
  on older distributions
- Drop perl(Test::ClassAPI) buildreq for now

* Wed Feb 27 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.201-3
- Rebuild for perl 5.10 (again)

* Sun Jan 13 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.201-2
- Rebuild for new perl

* Wed Dec 19 2007 Tom "spot" Callaway <tcallawa@redhat.com> - 1.201-1
- Bump to 1.201

* Sat Sep 23 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.118-1
- Update to 1.118.

* Wed Sep  6 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.117-1
- Update to 1.117.

* Sun Jun  4 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.115-2
- Removed the perl(IO::Scalar) build requirement.

* Sun Jun  4 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.115-1
- Update to 1.115.

* Wed May 10 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.113-1
- Update to 1.113.

* Tue Apr 25 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.112-1
- Update to 1.112.

* Sat Apr 22 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.111-1
- First build.
